@@ -6,7 +6,7 @@ use FindBin qw($Bin);
 my $path = $Bin;
 my $tx = Text::Xslate->new(
     path      => [$path],
-    cache_dir =>  $path,
+    cache_dir => '.eg_cache',
 );
 
 print $tx->render('hello.tx', { });
